==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/hu.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to contain at least one lower and one upper case character." : "A jelszónak legalább egy kisbetűt és legalább egy nagybetűt kell tartalmaznia.",
    "Password needs to contain at least one numeric character." : "A jelszónak legalább egy numerikus karaktert kell tartalmaznia.",
    "Password needs to contain at least one special character." : "A jelszónak legalább egy speciális karaktert kell tartalmaznia.",
    "Password policy" : "Jelszó házirend",
    "Minimal length" : "Minimális hossz",
    "Forbid common passwords" : "Egyszerű jelszavak tiltása",
    "Enforce upper and lower case characters" : "Nagybetűs és kisbetűs karakterek megkövetelése",
    "Enforce numeric characters" : "Numerikus karakterek megkövetelése",
    "Enforce special characters" : "Speciális karakterek megkövetelése",
    "Password need to be at least %s characters long" : "A jelszónak legalább %s karakter hosszúságúnak kell lennie",
    "Password need to contain at least one lower case character and one upper case character." : "A jelszónak legalább egy kisbetűt és legalább egy nagybetűt kell tartalmaznia.",
    "Password need to contain at least one numeric character." : "A jelszónak legalább egy numerikus karaktert kell tartalmaznia.",
    "Password need to contain at least one special character." : "A jelszónak legalább egy speciális karaktert kell tartalmaznia.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "A jelszó benne van az 1.000.000 leggyakoribb jelszó listájában. Kérlek válassz másikat."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/hu.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "A jelszó legalább %s karakter hosszú kell legyen",
    "Password needs to contain at least one lower and one upper case character." : "A jelszónak legalább egy kisbetűt és legalább egy nagybetűt kell tartalmaznia.",
    "Password needs to contain at least one numeric character." : "A jelszónak legalább egy numerikus karaktert kell tartalmaznia.",
    "Password needs to contain at least one special character." : "A jelszónak legalább egy speciális karaktert kell tartalmaznia.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A jelszó az 1.000.000 leggyakoribb között van. Kérlek tedd egyedivé.",
    "Password policy" : "Jelszó házirend",
    "Minimal length" : "Minimális hossz",
    "Forbid common passwords" : "Egyszerű jelszavak tiltása",
    "Enforce upper and lower case characters" : "Nagybetűs és kisbetűs karakterek megkövetelése",
    "Enforce numeric characters" : "Numerikus karakterek megkövetelése",
    "Enforce special characters" : "Speciális karakterek megkövetelése",
    "Password need to be at least %s characters long" : "A jelszónak legalább %s karakter hosszúságúnak kell lennie",
    "Password need to contain at least one lower case character and one upper case character." : "A jelszónak legalább egy kisbetűt és legalább egy nagybetűt kell tartalmaznia.",
    "Password need to contain at least one numeric character." : "A jelszónak legalább egy numerikus karaktert kell tartalmaznia.",
    "Password need to contain at least one special character." : "A jelszónak legalább egy speciális karaktert kell tartalmaznia.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "A jelszó benne van az 1.000.000 leggyakoribb jelszó listájában. Kérlek válassz másikat."
},
"nplurals=2; plural=(n != 1);");
